@@ -5,9 +5,12 @@ from typing import Collection, Dict, List, Tuple, Union
 from pydantic import parse_raw_as
 
 from metaphor.common.base_extractor import BaseExtractor
-from metaphor.common.entity_id import dataset_fullname, to_dataset_entity_id
+from metaphor.common.entity_id import (
+    dataset_fullname,
+    to_dataset_entity_id,
+    to_dataset_entity_id_from_logical_id,
+)
 from metaphor.common.event_util import ENTITY_TYPES
-from metaphor.common.filter import DatabaseFilter
 from metaphor.common.logger import get_logger
 from metaphor.common.utils import start_of_day, unique_list
 from metaphor.models.crawler_run_metadata import Platform
@@ -19,6 +22,7 @@ from metaphor.models.metadata_change_event import (
 )
 from metaphor.snowflake import auth
 from metaphor.snowflake.accessed_object import AccessedObject
+from metaphor.snowflake.extractor import DEFAULT_FILTER
 from metaphor.snowflake.lineage.config import SnowflakeLineageRunConfig
 from metaphor.snowflake.utils import QueryWithParam, async_execute
 
@@ -28,9 +32,6 @@ logger = get_logger(__name__)
 logging.getLogger("Parser").setLevel(logging.CRITICAL)
 
 
-DEFAULT_EXCLUDED_DATABASES: DatabaseFilter = {"SNOWFLAKE": None}
-
-
 SUPPORTED_OBJECT_DOMAIN_TYPES = (
     "TABLE",
     "VIEW",
@@ -50,12 +51,13 @@ class SnowflakeLineageExtractor(BaseExtractor):
     def __init__(self, config: SnowflakeLineageRunConfig):
         super().__init__(config, "Snowflake data lineage crawler", Platform.SNOWFLAKE)
         self._account = config.account
-        self._filter = config.filter.normalize()
+        self._filter = config.filter.normalize().merge(DEFAULT_FILTER)
         self._max_concurrency = config.max_concurrency
         self._batch_size = config.batch_size
         self._lookback_days = config.lookback_days
         self._enable_view_lineage = config.enable_view_lineage
         self._enable_lineage_from_history = config.enable_lineage_from_history
+        self._include_self_lineage = config.include_self_lineage
 
         self._conn = auth.connect(config)
         self._datasets: Dict[str, Dataset] = {}
@@ -64,12 +66,6 @@ class SnowflakeLineageExtractor(BaseExtractor):
 
         logger.info("Fetching lineage info from Snowflake")
 
-        self._filter.excludes = (
-            DEFAULT_EXCLUDED_DATABASES
-            if self._filter.excludes is None
-            else {**self._filter.excludes, **DEFAULT_EXCLUDED_DATABASES}
-        )
-
         start_date = start_of_day(self._lookback_days)
 
         with self._conn:
@@ -203,8 +199,17 @@ class SnowflakeLineageExtractor(BaseExtractor):
                 name=full_name, account=self._account, platform=DataPlatform.SNOWFLAKE
             )
 
+            filtered_source_datasets = source_datasets.copy()
+            if not self._include_self_lineage:
+                try:
+                    entity_id = to_dataset_entity_id_from_logical_id(logical_id)
+                    filtered_source_datasets.remove(str(entity_id))
+                except ValueError:
+                    # Nothing to remove if there's no self lineage
+                    pass
+
             upstream = DatasetUpstream(
-                source_datasets=source_datasets, transformation=query
+                source_datasets=filtered_source_datasets, transformation=query
             )
 
             self._datasets[full_name] = Dataset(
