@@ -132,7 +132,7 @@ class ThoughtSpotExtractor(BaseExtractor):
             self._virtual_views[table_id] = view
 
     @staticmethod
-    def build_column_expr_map(tml):
+    def build_column_expr_map(tml: TMLObject):
         def build_formula_map(tml_table):
             formula_map = {}
             for f in tml_table.formulas:
@@ -303,6 +303,7 @@ class ThoughtSpotExtractor(BaseExtractor):
                     thought_spot=ThoughtSpotInfo(
                         type=ThoughtSpotDashboardType.LIVEBOARD,
                         tags=self._tag_names(board.header.tags),
+                        embed_url=f"{self._base_url}/#/embed/viz/{board_id}",
                     ),
                 ),
                 source_info=SourceInfo(
